// 对Date的扩展，将 Date 转化为指定格式的String
// 月(M)、日(d)、小时(h)、分(m)、秒(s)、季度(q) 可以用 1-2 个占位符， 
// 年(y)可以用 1-4 个占位符，毫秒(S)只能用 1 个占位符(是 1-3 位的数字) 
// 例子： 
// (new Date()).Format("yyyy-MM-dd hh:mm:ss.S") ==> 2006-07-02 08:09:04.423 
// (new Date()).Format("yyyy-M-d h:m:s.S")      ==> 2006-7-2 8:9:4.18 

Date.prototype.Format = function(formatStr) {
	var str = formatStr;
	var Week = [ '日', '一', '二', '三', '四', '五', '六' ];
	str = str.replace(/yyyy|YYYY/, this.getFullYear());
	str = str.replace(/yy|YY/, (this.getYear() % 100) > 9 ? (this.getYear() % 100).toString() : '0' + (this.getYear() % 100));
	str = str.replace(/MM/, (this.getMonth()+1) > 9 ? (this.getMonth()+1).toString() : '0' + (this.getMonth()+1));
	str = str.replace(/M/g, (this.getMonth()+1));
	str = str.replace(/w|W/g, Week[this.getDay()]);
	str = str.replace(/dd|DD/, this.getDate() > 9 ? this.getDate().toString() : '0' + this.getDate());
	str = str.replace(/d|D/g, this.getDate());
	str = str.replace(/hh|HH/, this.getHours() > 9 ? this.getHours().toString() : '0' + this.getHours());
	str = str.replace(/h|H/g, this.getHours());
	str = str.replace(/mm/, this.getMinutes() > 9 ? this.getMinutes().toString() : '0' + this.getMinutes());
	str = str.replace(/m/g, this.getMinutes());
	str = str.replace(/ss|SS/, this.getSeconds() > 9 ? this.getSeconds().toString() : '0' + this.getSeconds());
	str = str.replace(/s|S/g, this.getSeconds());
	return str;
}

// 求两个时间的天数差 日期格式为 YYYY-MM-dd
function daysBetween(DateOne, DateTwo) {
	var OneMonth = DateOne.substring(5, DateOne.lastIndexOf('-'));
	var OneDay = DateOne.substring(DateOne.length, DateOne.lastIndexOf('-') + 1);
	var OneYear = DateOne.substring(0, DateOne.indexOf('-'));
	var TwoMonth = DateTwo.substring(5, DateTwo.lastIndexOf('-'));
	var TwoDay = DateTwo.substring(DateTwo.length, DateTwo.lastIndexOf('-') + 1);
	var TwoYear = DateTwo.substring(0, DateTwo.indexOf('-'));
	var cha = ((Date.parse(OneMonth + '/' + OneDay + '/' + OneYear) - Date.parse(TwoMonth + '/' + TwoDay + '/' + TwoYear)) / 86400000);
	return Math.abs(cha);
}

// 日期计算
Date.prototype.DateAdd = function(strInterval, Number) {
	var dtTmp = this;
	switch (strInterval) {
	case 's':
		return new Date(Date.parse(dtTmp) + (1000 * Number));
	case 'n':
		return new Date(Date.parse(dtTmp) + (60000 * Number));
	case 'h':
		return new Date(Date.parse(dtTmp) + (3600000 * Number));
	case 'd':
		return new Date(Date.parse(dtTmp) + (86400000 * Number));
	case 'w':
		return new Date(Date.parse(dtTmp) + ((86400000 * 7) * Number));
	case 'q':
		return new Date(dtTmp.getFullYear(), (dtTmp.getMonth()) + Number * 3, dtTmp.getDate(), dtTmp.getHours(), dtTmp.getMinutes(), dtTmp.getSeconds());
	case 'm':
		return new Date(dtTmp.getFullYear(), (dtTmp.getMonth()) + Number, dtTmp.getDate(), dtTmp.getHours(), dtTmp.getMinutes(), dtTmp.getSeconds());
	case 'y':
		return new Date((dtTmp.getFullYear() + Number), dtTmp.getMonth(), dtTmp.getDate(), dtTmp.getHours(), dtTmp.getMinutes(), dtTmp.getSeconds());
	}
}

// 比较日期差 dtEnd 格式为日期型或者 有效日期格式字符串
Date.prototype.DateDiff = function(strInterval, dtEnd) {
	var dtStart = this;
	if (typeof dtEnd == 'string')// 如果是字符串转换为日期型
	{
		dtEnd = formatDate(dtEnd);
	}
	switch (strInterval) {
	case 's':
		return parseInt((dtEnd - dtStart) / 1000);
	case 'n':
		return parseInt((dtEnd - dtStart) / 60000);
	case 'h':
		return parseInt((dtEnd - dtStart) / 3600000);
	case 'd':
		return parseInt((dtEnd - dtStart) / 86400000);
	case 'w':
		return parseInt((dtEnd - dtStart) / (86400000 * 7));
	case 'm':
		return (dtEnd.getMonth() + 1) + ((dtEnd.getFullYear() - dtStart.getFullYear()) * 12) - (dtStart.getMonth() + 1);
	case 'y':
		return dtEnd.getFullYear() - dtStart.getFullYear();
	}
}

// 日期输出字符串，重载了系统的toString方法
Date.prototype.toString = function(showWeek) {
	var myDate = this;
	var str = myDate.toLocaleDateString();
	if (showWeek) {
		var Week = [ '日', '一', '二', '三', '四', '五', '六' ];
		str += ' 星期' + Week[myDate.getDay()];
	}
	return str;
}

// 日期时间检查
// | 格式为：YYYY-MM-DD HH:MM:SS
function CheckDateTime(str) {
	var reg = /^(\d+)-(\d{ 1,2 })-(\d{ 1,2 }) (\d{ 1,2 }):(\d{ 1,2 }):(\d{ 1,2 })$/;
	var r = str.match(reg);
	if (r == null)
		return false;
	r[2] = r[2] - 1;
	var d = new Date(r[1], r[2], r[3], r[4], r[5], r[6]);
	if (d.getFullYear() != r[1])
		return false;
	if (d.getMonth() != r[2])
		return false;
	if (d.getDate() != r[3])
		return false;
	if (d.getHours() != r[4])
		return false;
	if (d.getMinutes() != r[5])
		return false;
	if (d.getSeconds() != r[6])
		return false;
	return true;
}

// 取得日期数据信息
// | 参数 interval 表示数据类型
// | y 年 m月 d日 w星期 ww周 h时 n分 s秒
Date.prototype.DatePart = function(interval) {
	var myDate = this;
	var partStr = '';
	var Week = [ '日', '一', '二', '三', '四', '五', '六' ];
	switch (interval) {
	case 'y':
		partStr = myDate.getFullYear();
		break;
	case 'm':
		partStr = myDate.getMonth() + 1;
		break;
	case 'd':
		partStr = myDate.getDate();
		break;
	case 'w':
		partStr = Week[myDate.getDay()];
		break;
	case 'ww':
		partStr = myDate.WeekNumOfYear();
		break;
	case 'h':
		partStr = myDate.getHours();
		break;
	case 'n':
		partStr = myDate.getMinutes();
		break;
	case 's':
		partStr = myDate.getSeconds();
		break;
	}
	return partStr;
}

// 字符串转成日期类型
// | 格式 MM/dd/YYYY MM-dd-YYYY YYYY/MM/dd YYYY-MM-dd
function StringToDate(DateStr) {
	var converted = Date.parse(DateStr);
	var myDate = new Date(converted);
	if (isNaN(myDate)) {
		// var delimCahar = DateStr.indexOf('/')!=-1?'/':'-';
		var arys = DateStr.split('-');
		myDate = new Date(arys[0], --arys[1], arys[2]);
	}
	return myDate;
}


// ==========================================

// 判断时间是否相等
function isDateNow(date1, date2) {
	console.log(date1);
	console.log(date2);
	console.log(dateUtil.getNow(date2));
	if (dateUtil.getNowDate(dateUtil.getNow(date1)).getTime() == dateUtil.getNowDate(dateUtil.getNow(date2)).getTime()) {
		return 1;
	}
	return 0;
}

// 缺位补 0
function addZero(number) {
	if (number < 10) {
		number = '0' + number;
	}
	return number;
}

/**
 * 日期工具类
 */
var dateUtil = {
	// 获得指定日期,格式:yyyy-MM-dd
	getNowDate : function(myDate) {
		return new Date(myDate);
	},
	// 获得指定日期,格式:yyyy-MM-dd
	getNow : function(myDate) {
		var date = new Date(myDate);
		var y = date.getFullYear();
		var m = addZero(date.getMonth() + 1); // 获取当前月份的日期
		var d = addZero(date.getDate());
		return y + "-" + m + "-" + d;
	},
	// 格式化日期,格式:MM-dd HH:mm
	getNowMonth : function(myDate) {
		if (typeof (myDate) == "undefined") {
			return "";
		}
		var date = new Date(myDate);

		var m = addZero(date.getMonth() + 1); // 获取当前月份的日期
		var d = addZero(date.getDate());
		var h = addZero(myDate.getHours());
		var mins = addZero(myDate.getMinutes());
		return m + "-" + d + " " + h + ":" + mins;
	},
	// 格式化日期,格式:MM-dd HH:mm
	getNowDays : function(myDate) {
		if (typeof (myDate) == "undefined") {
			return "";
		}
		var date = new Date(myDate);
		var h = addZero(myDate.getHours());
		var mins = addZero(myDate.getMinutes());
		return h + ":" + mins;
	},
	// 获得当前日期 前/后X天的日期,格式:yyyy-MM-dd
	getAfterDate : function(dayCount) {
		var date = new Date();
		date.setDate(date.getDate() + dayCount); // 获取dayCount天后的日期
		var y = date.getFullYear();
		var m = addZero(date.getMonth() + 1);
		var d = (date.getDate());
		return y + "-" + m + "-" + d;
	},
	// 获得当前月,格式:yyyy-MM
	getNowMonth : function() {
		var date = new Date();
		var y = date.getFullYear();
		var m = addZero(date.getMonth() + 1); // 获取当前月份的日期
		return y + "-" + m;
	},
	// 获得当前月前X月的年月,格式:yyyy-MM
	getBeforeMonth : function(monthCount) {
		var date = new Date();
		date.setMonth(date.getMonth() + 1 - monthCount); // 获取dayCount天前的月
		var y = date.getFullYear();
		var m = addZero(date.getMonth());
		return y + "-" + m;
	},
	// 获得当前月后X月的年月,格式:yyyy-MM
	getAfterMonth : function(monthCount) {
		var date = new Date();
		date.setMonth(date.getMonth() + 1 - monthCount); // 获取dayCount天后的日期
		var y = date.getFullYear();
		var m = addZero(date.getMonth());
		return y + "-" + m;
	}
};